@@ -29,17 +29,21 @@ from datetime import datetime
 import astro_ghost
 from joblib import dump, load
 
-def getGHOST(real=False, verbose=False, installpath=''):
+def getGHOST(real=False, verbose=False, installpath='', clobber=False):
     if not installpath:
         try:
             installpath = os.environ['GHOST_PATH']
         except:
-            print("Couldn't find where you want to save GHOST. Saving in package path...")
+            print("Couldn't find where you want to save GHOST. Setting location to package path...")
             installpath = astro_ghost.__file__
             installpath = installpath.split("/")[:-1]
             installpath = "/".join(installpath)
     if not os.path.exists(installpath + '/database'):
         os.mkdir(installpath + '/database')
+    else:
+        if os.path.exists(installpath + '/database/GHOST.csv') & (clobber == False):      
+            print("GHOST database already exists in the install path!")
+            return
     if real:
         url = 'https://www.dropbox.com/s/a0fufc3827pfril/GHOST.csv?dl=1'
         r = requests.get(url)
