@@ -373,8 +373,8 @@ def gradientAscent(path, SN_dict, SN_dict_postDLR, SN_names, hostDF, transientDF
         except:
             print("Already have the folder quiverMaps!")
     for i in np.arange(len(step_sizes)):
-        try:
-        #if True:
+        #try:
+        if True:
             #clear buffer memory
             gc.collect()
 
@@ -704,8 +704,8 @@ def gradientAscent(path, SN_dict, SN_dict_postDLR, SN_names, hostDF, transientDF
                     #pickle.dump(SN_dict_postDLR, fp, protocol=pickle.HIGHEST_PROTOCOL)
                     dump(SN_dict_postDLR, fp)
                 hostDF.to_csv(path+"/hostDF_postGD.tar.gz", index=False)
-        except:
-             continue
+        #except:
+        #     continue
 
     with open(path+"/dictionaries/gals_postGD.p", 'wb') as fp:
         #pickle.dump(SN_dict_postDLR, fp, protocol=pickle.HIGHEST_PROTOCOL)
